Geometry
========
Handles geometry of the inversion task. This includes definition of reconstruction grid, creating artificial geometry and computation of geometry (sensitivity/contribution) matrices. Currently only algorithms using single line of sight approximation are implemented.

Geometry matrix
---------------

.. automodule:: tomotok.core.geometry.generators
    :members:
    :undoc-members:
    :noindex:

Reconstruction grids
--------------------

.. autoclass:: tomotok.core.geometry.RegularGrid
    :members:
    :noindex:


Lines of sight
--------------

.. automodule:: tomotok.core.geometry.los
    :members:
    :noindex:
